print("import: 'pytest_remotedata'")
import pytest_remotedata

print("import: 'pytest_doctestplus'")
import pytest_doctestplus

print("import: 'pytest_openfiles'")
import pytest_openfiles

print("import: 'pytest_arraydiff'")
import pytest_arraydiff

